import { GuildBasedChannel, GuildTextBasedChannel, PermissionsBitField } from "discord.js";
import client from "../client";

export async function getGuildChannel(guildID: string, channelID: string): Promise<GuildBasedChannel | null> {
    try {
        const guild = await client.guilds.fetch(guildID);
        if (!guild) return null;

        const channel = await guild.channels.fetch(channelID);
        return channel;
    } catch (_error) {
        return null;
    }
}

export async function getChannelPermission(channel: GuildTextBasedChannel): Promise<Readonly<PermissionsBitField> | null> {
    try {
        const guildMember = await channel.guild.members.fetchMe();
        if (!guildMember) return null;

        return channel.permissionsFor(guildMember);
    } catch (error) {
        return null;
    }
}